"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerRevertShapeshiftEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player (who is a shapeshifter) shapeshifts back into their own
 * form after being shapeshifted as another play for some duration of time.
 *
 * Use {@link PlayerShapeshiftEvent} to listen for when a player actually shapeshifts
 * initially.
 */
class PlayerRevertShapeshiftEvent extends events_1.RevertableEvent {
    constructor(room, player, message, 
    /**
     * The player that the player shapeshifted from.
     */
    target, 
    /**
     * Whether or not to show an animation of the player shapeshifting.
     */
    doAnimation) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.target = target;
        this.doAnimation = doAnimation;
        this.eventName = "player.revertshapeshift";
        this._alteredDoAnimation = doAnimation;
    }
    /**
     * Whether or not to show an animation of the player shapeshifting instead, if altered.
     */
    get alteredDoAnimation() {
        return this._alteredDoAnimation;
    }
    /**
     * Change whether or not an animation will show the player shapeshifting.
     * @param doAnimation Whether or not to do show an animation of the player shape shifting.
     */
    setDoAnimation(doAnimation) {
        this._alteredDoAnimation = doAnimation;
    }
}
exports.PlayerRevertShapeshiftEvent = PlayerRevertShapeshiftEvent;
PlayerRevertShapeshiftEvent.eventName = "player.revertshapeshift";
//# sourceMappingURL=RevertShapeshift.js.map