import { CancelableEvent } from "@skeldjs/events";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { BaseRole } from "../../roles";
import { RoomEvent } from "../RoomEvent";
/**
 * Emitted when SkeldJS assigns roles to each player, just after a game is started.
 * Can be canceled to avoid assigning roles entirely, or can be used to change
 * which roles are assigned to which players.
 *
 * Does not guarantee that the players' roles have actually been assigned, see
 * {@link PlayerSetRoleEvent}.
 */
export declare class RoomAssignRolesEvent<RoomType extends Hostable = Hostable> extends CancelableEvent implements RoomEvent {
    readonly room: RoomType;
    /**
     * The players that were chosen to be impostors.
     */
    readonly roleAssignments: Map<PlayerData, typeof BaseRole>;
    static eventName: "room.assignroles";
    eventName: "room.assignroles";
    private _alteredAssignments;
    constructor(room: RoomType, 
    /**
     * The players that were chosen to be impostors.
     */
    roleAssignments: Map<PlayerData, typeof BaseRole>);
    /**
     * Which roles to assign to which players instead, if changed.
     */
    get alteredAssignments(): Map<PlayerData<Hostable<any>>, typeof BaseRole>;
    /**
     * Change which roles to assign to which players.
     * @param roleAssignments The roles to assign instead.
     */
    setAssignments(roleAssignments: Map<PlayerData, typeof BaseRole>): void;
    /**
     * Change which role a player will get assigned.
     * @param player The player to change the assignment for.
     * @param assignment The role to assign for the player instead.
     */
    setAssignment(player: PlayerData, assignment: typeof BaseRole): void;
}
//# sourceMappingURL=AssignRoles.d.ts.map