"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerVoteState = exports.VoteStateSpecialId = void 0;
var VoteStateSpecialId;
(function (VoteStateSpecialId) {
    VoteStateSpecialId[VoteStateSpecialId["IsDead"] = 252] = "IsDead";
    VoteStateSpecialId[VoteStateSpecialId["SkippedVote"] = 253] = "SkippedVote";
    VoteStateSpecialId[VoteStateSpecialId["MissedVote"] = 254] = "MissedVote";
    VoteStateSpecialId[VoteStateSpecialId["NotVoted"] = 255] = "NotVoted";
})(VoteStateSpecialId = exports.VoteStateSpecialId || (exports.VoteStateSpecialId = {}));
/**
 * Represents a player's voting state.
 */
class PlayerVoteState {
    constructor(room, playerId, votedForId) {
        this.room = room;
        this.playerId = playerId;
        this.votedForId = votedForId;
    }
    /**
     * The player that this vote state is for.
     */
    get player() {
        return this.room.getPlayerByPlayerId(this.playerId);
    }
    /**
     * Whether the player that this state represents is dead.
     */
    get isDead() {
        return this.votedForId === VoteStateSpecialId.IsDead;
    }
    /**
     * Whether this player didn't vote by the end of the meeting.
     */
    get didMissVote() {
        return this.votedForId === VoteStateSpecialId.MissedVote;
    }
    /**
     * Whether this player skipped voting.
     */
    get didSkip() {
        return this.votedForId === VoteStateSpecialId.SkippedVote;
    }
    /**
     * Whether this player has either voted for a player or voted to skip.
     */
    get hasVoted() {
        return this.votedForId < VoteStateSpecialId.IsDead ||
            this.votedForId === VoteStateSpecialId.SkippedVote;
    }
    /**
     * The player that this player voted for, if any.
     */
    get votedFor() {
        return this.room.getPlayerByPlayerId(this.votedForId);
    }
}
exports.PlayerVoteState = PlayerVoteState;
//# sourceMappingURL=PlayerVoteState.js.map