"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AprilShipStatus = void 0;
const util_1 = require("@skeldjs/util");
const constant_1 = require("@skeldjs/constant");
const data_1 = require("@skeldjs/data");
const InnerShipStatus_1 = require("./InnerShipStatus");
const systems_1 = require("../systems");
const AutoOpenDoor_1 = require("../misc/AutoOpenDoor");
/**
 * Represents a room object for the April Fools' version of the The Skeld map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class AprilShipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netId, ownerid, flags, data) {
        super(room, spawnType, netId, ownerid, flags, data);
        this.initialSpawnCenter = new util_1.Vector2(0.72, 0.62);
        this.meetingSpawnCenter = new util_1.Vector2(0.72, 0.62);
    }
    getComponent(component) {
        if (this.spawnType === constant_1.SpawnType.AprilShipStatus && component === AprilShipStatus) {
            return this.components[0];
        }
        return super.getComponent(component);
    }
    Setup() {
        this.systems.set(constant_1.SystemType.Reactor, new systems_1.ReactorSystem(this, constant_1.SystemType.Reactor, {
            timer: 10000,
            completed: new Set,
        }));
        this.systems.set(constant_1.SystemType.Electrical, new systems_1.SwitchSystem(this, constant_1.SystemType.Electrical, {
            expected: [false, false, false, false, false],
            actual: [false, false, false, false, false],
            brightness: 255,
        }));
        this.systems.set(constant_1.SystemType.O2, new systems_1.LifeSuppSystem(this, constant_1.SystemType.O2, {
            timer: 10000,
            completed: new Set,
        }));
        this.systems.set(constant_1.SystemType.MedBay, new systems_1.MedScanSystem(this, constant_1.SystemType.MedBay, {
            queue: [],
        }));
        this.systems.set(constant_1.SystemType.Security, new systems_1.SecurityCameraSystem(this, constant_1.SystemType.Security, {
            players: new Set,
        }));
        this.systems.set(constant_1.SystemType.Communications, new systems_1.HudOverrideSystem(this, constant_1.SystemType.Communications, {
            sabotaged: false,
        }));
        this.systems.set(constant_1.SystemType.Doors, new systems_1.AutoDoorsSystem(this, constant_1.SystemType.Doors, {
            dirtyBit: 0,
            doors: [],
        }));
        this.systems.set(constant_1.SystemType.Sabotage, new systems_1.SabotageSystem(this, constant_1.SystemType.Sabotage, {
            cooldown: 0,
        }));
        const autodoor = this.systems.get(constant_1.SystemType.Doors);
        autodoor.doors = [
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 0, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 1, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 2, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 3, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 4, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 5, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 6, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 7, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 8, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 9, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 10, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 11, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 12, true),
            new AutoOpenDoor_1.AutoOpenDoor(autodoor, 13, true),
        ];
    }
    getDoorsInRoom(room) {
        return AprilShipStatus.roomDoors[room] || [];
    }
    getTasks() {
        return Object.values(data_1.TheSkeldTasks);
    }
}
exports.AprilShipStatus = AprilShipStatus;
AprilShipStatus.roomDoors = {
    [constant_1.SystemType.UpperEngine]: [2, 5],
    [constant_1.SystemType.Cafeteria]: [0, 3, 8],
    [constant_1.SystemType.MedBay]: [10],
    [constant_1.SystemType.Security]: [6],
    [constant_1.SystemType.Electrical]: [9],
    [constant_1.SystemType.Storage]: [1, 7, 12],
    [constant_1.SystemType.LowerEngine]: [4, 11]
};
//# sourceMappingURL=AprilShipStatus.js.map